This function will be removed in future versions.
Census data and boundary geographies are reproduced and distributed on an "as is" basis with the permission of Statistics Canada (Statistics Canada 2006; 2011; 2016).
Arguments
- dataset
A CensusMapper dataset identifier.
- regions
A named list of census regions to retrieve. Names must be valid census aggregation levels.
- level
The census aggregation level to retrieve, defaults to
"Regions". One of"Regions","PR","CMA","CD","CSD","CT"or"DA".- geo_format
By default is set to
NAand appends no geographic information. To include geographic information with census data, specify one of either"sf"to return ansfobject (requires thesfpackage) or"sp"to return aSpatialPolygonsDataFrame-classobject (requires thergdalpackage).- ...
Further arguments passed to
get_census.
Examples
# Query the API for data geographies in Vancouver, at the census subdivision
# level:
if (FALSE) { # \dontrun{
# Query the API for geographies in Vancouver, at the census subdivision
# level, and return the associated geography files in \code{sf} format:
census_data <- get_census(dataset='CA16', regions=list(CMA="59933"),
level='CSD', geo_format = "sf")
} # }