Read the Dissemination Geographies Relationship File
Source:R/geo_suite.R
get_statcan_geography_relationships.RdReads the Dissemination Geographies Relationship File for the given census year. The table contains the information on how all the geographic levels are related for each area. Data gets cached after first download if the cancensus cache path has been set. A reference guide is available at https://www150.statcan.gc.ca/n1/en/catalogue/982600032021001