Query the CensusMapper API for vectors with descriptions matching a search term or phrase (deprecated)
Source:R/vector_discovery.R
search_census_vectors.RdQuery the CensusMapper API for vectors with descriptions matching a search term or phrase (deprecated)
Arguments
- searchterm
The term or phrase to search for e.g.
"Ojibway". Search terms are case insensitive. If unable to find a given string, this function will suggest similarly named objects.- dataset
The dataset to query for available vectors, e.g.
"CA16".- type
One of
NA,'Total','Male'or'Female'. If specified, only return variables of specified `type`.- ...
Further arguments passed on to
list_census_vectors.