Cancensus requires a free Censusmapper API key to retrieve data. This function helps set the key for either the duration of the session (default) or permanently for use across sessions.
Arguments
- key
a Censusmapper API key. For more information on keys see the API key section
- overwrite
Option to overwrite any existing Censusmapper keys already stored locally.
- install
Option to install permanently for use across sessions.