Learn R Programming

cancensus (version 0.5.5)

get_statcan_wds_metadata: Query the StatCan WDS for metadata

Description

Get official metadata information from Statistics Canada for a given geographic level. Only available for the 2021 census. Data is cached for the duration of the R session.

Usage

get_statcan_wds_metadata(census_year, level, refresh = FALSE)

Value

tibble with the metadata

Arguments

census_year

census year to get the data for, right now only 2021 is supported

level

geographic level to return the data for, valid choices are "PR","CD","CMACA","CSD","CT","ADA","DA","ER","FED","DPL","POPCNTR"

refresh

default is `FALSE` will refresh the temporary cache if `TRUE`

Examples

Run this code
# get metadata for federal electoral districts
if (FALSE) {
get_statcan_wds_metadata(census_year="2021",level="FED")
}

Run the code above in your browser using DataLab