powered by
Get official metadata information from Statistics Canada for a given geographic level. Only available for the 2021 census. Data is cached for the duration of the R session.
get_statcan_wds_metadata(census_year, level, refresh = FALSE)
tibble with the metadata
census year to get the data for, right now only 2021 is supported
geographic level to return the data for, valid choices are "PR","CD","CMACA","CSD","CT","ADA","DA","ER","FED","DPL","POPCNTR"
default is `FALSE` will refresh the temporary cache if `TRUE`
# get metadata for federal electoral districts if (FALSE) { get_statcan_wds_metadata(census_year="2021",level="FED") }
Run the code above in your browser using DataLab